# SSL Metrics

> Helper package that will install all `ssl-metrics` packages at once

## About

This project is simply a wrapper/ helper program that installs all of the other `ssl-metrics` projects.

## Included Projects

- [ssl-metrics-badges](https://github.com/SoftwareSystemsLaboratory/ssl-metrics-badges)
- [ssl-metrics-git-bus-factor](https://github.com/SoftwareSystemsLaboratory/ssl-metrics-git-bus-factor)
- [ssl-metrics-git-commits-loc](https://github.com/SoftwareSystemsLaboratory/ssl-metrics-git-commits-loc)
- [ssl-metrics-github-issues](https://github.com/SoftwareSystemsLaboratory/ssl-metrics-github-issues)
- [ssl-metrics-git-commits-loc](https://github.com/SoftwareSystemsLaboratory/ssl-metrics-git-commits-loc)
- [ssl-metrics-json-converter](https://github.com/SoftwareSystemsLaboratory/ssl-metrics-json-converter)

## How to Install

### From pip

1. Install `Python 3.9.6 +`
2. (Recommended) Create a *virtual environment* with `python3.9 -m venv env` and *activate* it
3. Run `pip install ssl-metrics-meta`
4. To run any of the installed packages, see their specific documentation pages for more information
